@@ -4,7 +4,7 @@ package WWW::Search::Ebay;
 use strict;
 use warnings;
 
-our $VERSION = 2.275;
+our $VERSION = 2.276;
 
 =head1 NAME
 
@@ -186,6 +186,7 @@ sub _native_setup_search
                          # Output basic HTML, not JavaScript:
                          _armrs => 1,
                         };
+    # https://www.ebay.com/sch/i.html?LH_Auction=1&SortProperty=MetaEndSort&_armrs=1&_ipg=200&_fosrp=1&_nkw=zeppelin&_sop=1
     $self->{_options} = {
                          _nkw => $native_query,
                          _armrs => 1,
@@ -394,7 +395,7 @@ sub _parse_price
     {
     print STDERR " DDD   try TDprice ===$s===\n";
     } # if
-  if ($oTDprice->attr('class') =~ m/\bebcBid\b/)
+  if ($oTDprice->attr('class') =~ m'\bebcBid\b')
     {
     # If we see this, we must have been searching for Stores items
     # but we ran off the bottom of the Stores item list and ran
@@ -404,7 +405,7 @@ sub _parse_price
     # maybe just maybe we hit this because of a parsing glitch which
     # might correct itself on the next TD.
     } # if
-  if ($oTDprice->attr('class') !~ m/(ebcPr|prices?|prc)/)
+  if ($oTDprice->attr('class') !~ m'\b(ebcPr|prices|prc)\b')
     {
     # If we see this, we probably were searching for Store items
     # but we ran off the bottom of the Store item list and ran
@@ -446,7 +447,6 @@ sub _parse_price
     {
     $hit->shipping('free');
     } # if
-  print STDERR " DDD   good final iPrice ===$iPrice===\n" if  (DEBUG_COLUMNS || (1 < $self->{_debug}));
   $hit->bid_amount($iPrice);
   return 1;
   } # _parse_price
@@ -525,8 +525,6 @@ sub _parse_shipping
   # I don't know why there are sometimes weird characters in there:
   $iPrice =~ s!&Acirc;!!g;
   $iPrice =~ s!!!g;
-  $iPrice =~ s!\+!!g;
-  $iPrice =~ s/SHIPPING//gi;
   print STDERR " DDD   raw shipping ===$iPrice===\n" if (DEBUG_COLUMNS || (1 < $self->{_debug}));
   if ($iPrice =~ m/UNKNOWN/i)
     {
@@ -579,34 +577,10 @@ sub _parse_enddate
     $hit->change_date($sDate);
     return 1;
     }
-  print STDERR " DDD   raw     sDateTemp ===$sDateTemp===\n" if (DEBUG_DATES || (1 < $self->{_debug}));
-  # I don't know why there are sometimes weird characters in there:
-  $sDateTemp =~ s!&Acirc;!!g;
-  $sDateTemp =~ s!!!g;
-  $sDateTemp =~ s!<!!;
-  $sDateTemp =~ tr!()!!d;
-  # Convert nbsp to regular space:
-  $sDateTemp =~ s!\240!\040!g;
-  $sDateTemp =~ s!Time\s+left:?\s*!!g;
-  $sDateTemp =~ s!\s+left!!g;
-  print STDERR " DDD   poached sDateTemp ===$sDateTemp===\n" if (DEBUG_DATES || (1 < $self->{_debug}));
-  my $date;
   if (ref($oTDdate))
     {
     my $sClass = $oTDdate->attr('class') || q{};
-    if ($sClass =~ m/time-end/)
-      {
-      $date = Date_Parse($sDateTemp);
-      # Fall through and continue
-      }
-    elsif ($sClass =~ m/time(-(left|-soon))?/)
-      {
-      $sDateTemp = $self->_process_date_abbrevs($sDateTemp);
-      # print STDERR " DDD   official time =====$self->{_ebay_official_time}=====\n" if (DEBUG_DATES || (1 < $self->{_debug}));
-      $date = DateCalc($self->{_ebay_official_time}, " + $sDateTemp");
-      # Fall through and continue
-      }
-    elsif ($sClass !~ m/(col3|ebcTim|ti?me)/)
+    if ($sClass !~ m/\b(col3|ebcTim|ti?me)\b/)
       {
       # If we see this, we probably were searching for Buy-It-Now items
       # but we ran off the bottom of the item list and ran into the list
@@ -614,12 +588,8 @@ sub _parse_enddate
       return 0;
       # There is a separate backend for searching Store items!
       } # if
-    else
-      {
-      warn " EEE did not match time/date class '$sClass'";
-      return 1;
-      }
     } # if
+  print STDERR " DDD   raw    sDateTemp ===$sDateTemp===\n" if (DEBUG_DATES || (1 < $self->{_debug}));
   if ($sDateTemp =~ m/---/)
     {
     # If we see this, we probably were searching for Buy-It-Now items
@@ -628,7 +598,17 @@ sub _parse_enddate
     return 0;
     # There is a separate backend for searching Store items!
     } # if
-  print STDERR " DDD   cooked  sDateTemp ===$sDateTemp===\n" if (DEBUG_DATES || (1 < $self->{_debug}));
+  # I don't know why there are sometimes weird characters in there:
+  $sDateTemp =~ s!&Acirc;!!g;
+  $sDateTemp =~ s!!!g;
+  $sDateTemp =~ s!<!!;
+  # Convert nbsp to regular space:
+  $sDateTemp =~ s!\240!\040!g;
+  $sDateTemp =~ s!Time\s+left:!!g;
+  $sDateTemp = $self->_process_date_abbrevs($sDateTemp);
+  print STDERR " DDD   cooked sDateTemp ===$sDateTemp===\n" if (DEBUG_DATES || (1 < $self->{_debug}));
+  print STDERR " DDD   official time =====$self->{_ebay_official_time}=====\n" if (DEBUG_DATES || (1 < $self->{_debug}));
+  my $date = DateCalc($self->{_ebay_official_time}, " + $sDateTemp");
   print STDERR " DDD   date ===$date===\n" if (DEBUG_DATES || (1 < $self->{_debug}));
   $sDate = $self->_format_date($date);
   print STDERR " DDD   sDate ===$sDate===\n" if (DEBUG_DATES || (1 < $self->{_debug}));
@@ -666,10 +646,8 @@ sub result_as_HTML
   my $sPrice = $self->_bidamount_as_text($oSR);
   my $sEndedColor = 'green';
   my $sEndedWord = 'ends';
-  my $dateNow = ParseDate('now');
-  print STDERR " DDD compare end_date ==$dateEnd==\n" if (DEBUG_DATES || (1 < $self->{_debug}));
-  print STDERR " DDD compare date_now ==$dateNow==\n" if (DEBUG_DATES || (1 < $self->{_debug}));
-  if ((Date_Cmp($dateEnd, $dateNow) || 0) < 0)
+  print STDERR " DDD compare end_date ==$dateEnd== to now\n" if (DEBUG_DATES || (1 < $self->{_debug}));
+  if ((Date_Cmp($dateEnd, 'now') || 0) < 0)
     {
     $sEndedColor = 'red';
     $sEndedWord = 'ended';
@@ -739,21 +717,13 @@ sub _get_result_count_elements
                             class => 'count'
                            );
   push @ao, $tree->look_down(
-                             '_tag' => 'div',
-                             class => 'pageCaptionDiv'
-                            );
+                            '_tag' => 'div',
+                            class => 'pageCaptionDiv'
+                           );
   push @ao, $tree->look_down( # for BySellerID as of 2010-07
-                             '_tag' => 'div',
-                             id => 'rsc'
-                            );
-  push @ao, $tree->look_down( # for Category, as of 2018-02:
-                             _tag => 'h2',
-                             class => 'srp-controls__count-heading'
-                            );
-  push @ao, $tree->look_down( # new as of 2018-02:
-                             _tag => 'h1',
-                             class => 'srp-controls__count-heading'
-                            );
+                            '_tag' => 'div',
+                            id => 'rsc'
+                           );
   return @ao;
   } # _get_result_count_elements
 
@@ -771,6 +741,7 @@ sub _get_itemtitle_tds
   {
   my $self = shift;
   my $tree = shift;
+  printf STDERR (" TTT this is Ebay::_get_itemtitle_tds") if (1 < $self->{_debug});
   my @ao = $tree->look_down(_tag => 'td',
                             class => 'details',
                            );
@@ -796,9 +767,7 @@ sub _get_itemtitle_tds
                                class => 'lvtitle',
                               );
     } # if
-  push @ao, $tree->look_down(_tag => 'div',
-                             class => 's-item__info clearfix',
-                            );
+  # printf STDERR (" DDD found %d itemtitle tags", scalar(@ao)) if (1 < $self->{_debug});
   return @ao;
   } # _get_itemtitle_tds
 
@@ -904,6 +873,10 @@ sub _parse_tree
       $self->approximate_result_count(0 + $sCount);
       last FONT;
       } # if
+    else
+      {
+      print STDERR " WWW     DID NOT MATCH\n" if (1 < $self->{_debug});
+      }
     } # foreach FONT
 
   if ($self->approximate_result_count() < 1)
@@ -933,7 +906,7 @@ sub _parse_tree
   my @aoTD = $self->_get_itemtitle_tds($tree);
   unless (@aoTD)
     {
-    print STDERR " EEE did not find table of results\n" if $self->{_debug};
+    print STDERR " EEE did not find any result title tags\n" if $self->{_debug};
     # use File::Slurp;
     # write_file('no-results.html', $self->{response}->content);
     } # unless
@@ -948,8 +921,15 @@ sub _parse_tree
     # First A tag contains the url & title:
     my $oA = $oTDtitle->look_down('_tag', 'a');
     next TD unless ref $oA;
-    # This is needed for Ebay::UK to make sure we're looking at the right TD:
     my $sTitle = $oA->as_text || '';
+    if ($sTitle eq '')
+      {
+      my $oImg = $oA->look_down(_tag => 'img');
+      if (defined $oImg)
+        {
+        $sTitle = $oImg->attr('alt') || '';
+        } # end if
+      } # end if
     next TD if ($sTitle eq '');
     print STDERR " DDD   sTitle ===$sTitle===\n" if (1 < $self->{_debug});
     my $oURI = URI->new($oA->attr('href'));
@@ -975,8 +955,7 @@ sub _parse_tree
     $hit->bid_count(0);
     # The rest of the info about this item is in sister <LI> elements
     # to the right:
-    my @aoSibs = $oTDtitle->look_down(_tag => q/span/);
-    push @aoSibs, $oTDtitle->parent->look_down(_tag => q/li/);
+    my @aoSibs = $oTDtitle->parent->parent->look_down(_tag => q{li});
     # The parent itself is an <LI> tag:
     shift @aoSibs;
     warn " DDD before loop, there are ", scalar(@aoSibs), " sibling TDs\n" if (1 < $self->{_debug});
@@ -989,8 +968,13 @@ sub _parse_tree
       if ($sColumn eq q{})
         {
         warn " WWW auction info sibling has no class ==$s==" if (DEBUG_COLUMNS || (1 < $self->{_debug}));
+        if ($s =~ m/The item is listed as a Top Rated Plus item/)
+          {
+          # Note: These items screw up the ByEndDate results because
+          # they appear out of order.
+          } # if
         } # if
-      print STDERR " DDD   looking at sibling TD whose class is '$sColumn' ===$s===\n" if (DEBUG_COLUMNS || (1 < $self->{_debug}));
+      print STDERR " DDD   looking at TD'$sColumn' ===$s===\n" if (DEBUG_COLUMNS || (1 < $self->{_debug}));
       if ($sColumn =~ m'price')
         {
         next TD unless $self->_parse_price($oTDsib, $hit);
